@@ -69,84 +69,106 @@ std::vector<std::pair<std::string, std::string> > GetUsage()
 {
   typedef std::pair<std::string, std::string> mp;
   std::vector<mp> s;
-  s.push_back(mp("Geometry options:", ""));
+  s.push_back(mp("(Related option names, if any, are given between parentheses)", ""));
+  s.push_back(mp("Geometry:", ""));
   s.push_back(mp("-0", "Output model, then exit"));
-  s.push_back(mp("-tol value", "Set geometrical tolerance"));
+  s.push_back(mp("-tol value", "Set geometrical tolerance (Geometry.Tolerance)"));
   s.push_back(mp("-match", "Match geometries and meshes"));
-  s.push_back(mp("Mesh options:", ""));
+  s.push_back(mp("Mesh:", ""));
   s.push_back(mp("-1, -2, -3", "Perform 1D, 2D or 3D mesh generation, then exit"));
   s.push_back(mp("-save", "Save mesh, then exit"));
   s.push_back(mp("-o file", "Specify output file name"));
-  s.push_back(mp("-format string", "Select output mesh format (" +
-                 GetKnownFileFormats(true) + ")"));
-  s.push_back(mp("-bin", "Create binary files when possible"));
+  s.push_back(mp("-format string", "Select output mesh format: " +
+                 GetKnownFileFormats(true) + " (Mesh.Format)"));
+  s.push_back(mp("-bin", "Create binary files when possible (Mesh.Binary)"));
   s.push_back(mp("-refine", "Perform uniform mesh refinement, then exit"));
   s.push_back(mp("-barycentric_refine", "Perform barycentric mesh refinement, "
                  "then exit"));
   s.push_back(mp("-reclassify angle", "Reclassify surface mesh, then exit"));
   s.push_back(mp("-reparam angle", "Reparametrize surface mesh, then exit"));
-  s.push_back(mp("-part int", "Partition after batch mesh generation"));
-  s.push_back(mp("-part_weight tri|quad|tet|hex|pri|pyr|trih int",
-                 "Weight of a triangle/quad/etc. during partitioning"));
-  s.push_back(mp("-part_split", "Save mesh partitions in separate files"));
-  s.push_back(mp("-part_[no_]topo", "Create the partition topology"));
-  s.push_back(mp("-part_[no_]ghosts", "Create ghost cells"));
-  s.push_back(mp("-part_[no_]physicals", "Create physical groups for partitions"));
-  s.push_back(mp("-part_topo_pro", "Save the partition topology .pro file"));
+  s.push_back(mp("-part int", "Partition after batch mesh generation "
+                 "(Mesh.NbPartitions)"));
+  s.push_back(mp("-part_weight [tri,quad,tet,hex,pri,pyr,trih] int",
+                 "Weight of a triangle/quad/etc. during partitioning "
+                 "(Mesh.Partition[Tri,Quad,...]Weight)"));
+  s.push_back(mp("-part_split", "Save mesh partitions in separate files "
+                 "(Mesh.PartitionSplitMeshFiles)"));
+  s.push_back(mp("-part_[no_]topo", "Create the partition topology "
+                 "(Mesh.PartitionCreateTopology)"));
+  s.push_back(mp("-part_[no_]ghosts", "Create ghost cells "
+                 "(Mesh.PartitionCreateGhostCells)"));
+  s.push_back(mp("-part_[no_]physicals", "Create physical groups for partitions "
+                 "(Mesh.PartitionCreatePhysicals)"));
+  s.push_back(mp("-part_topo_pro", "Save the partition topology .pro file "
+                 "(Mesh.PartitionTopologyFile)"));
   s.push_back(mp("-preserve_numbering_msh2", "Preserve element numbering in MSH2 "
-                 "format"));
-  s.push_back(mp("-save_all", "Save all elements (discard physical group definitions)"));
-  s.push_back(mp("-save_parametric", "Save nodes with their parametric coordinates"));
-  s.push_back(mp("-save_topology", "Save model topology"));
-  s.push_back(mp("-algo string", "Select mesh algorithm (meshadapt, del2d, front2d, "
-                 "delquad, del3d, front3d, mmg3d, pack, hxt)"));
-  s.push_back(mp("-smooth int", "Set number of mesh smoothing steps"));
-  s.push_back(mp("-order int", "Set mesh order (1, ..., 5)"));
-  s.push_back(mp("-optimize[_netgen]", "Optimize quality of tetrahedral elements"));
+                 "format (Mesh.PreserveNumberingMsh2)"));
+  s.push_back(mp("-save_all", "Save all elements (Mesh.SaveAll)"));
+  s.push_back(mp("-save_parametric", "Save nodes with their parametric coordinates "
+                 "(Mesh.SaveParametric)"));
+  s.push_back(mp("-save_topology", "Save model topology (Mesh.SaveTopology)"));
+  s.push_back(mp("-algo string", "Select mesh algorithm: auto, meshadapt, del2d, front2d, "
+                 "delquad, pack, del3d, front3d, mmg3d, hxt (Mesh.Algorithm and"
+                 "Mesh.Algorithm3D)"));
+  s.push_back(mp("-smooth int", "Set number of mesh smoothing steps (Mesh.Smoothing)"));
+  s.push_back(mp("-order int", "Set mesh order (Mesh.ElementOrder)"));
+  s.push_back(mp("-optimize[_netgen]", "Optimize quality of tetrahedral elements "
+                 "(Mesh.Optimize[Netgen])"));
   s.push_back(mp("-optimize_threshold", "Optimize tetrahedral elements that have a "
-                 "quality less than a threshold"));
-  s.push_back(mp("-optimize_ho", "Optimize high order meshes"));
-  s.push_back(mp("-ho_[min,max,nlayers]", "High-order optimization parameters"));
-  s.push_back(mp("-clscale value", "Set global mesh element size scaling factor"));
-  s.push_back(mp("-clmin value", "Set minimum mesh element size"));
-  s.push_back(mp("-clmax value", "Set maximum mesh element size"));
-  s.push_back(mp("-clcurv value", "Compute mesh element size from curvatures (value "
-                 "is the number of elements per 2*pi radians)"));
-  s.push_back(mp("-aniso_max value", "Set maximum anisotropy (for bamg)"));
+                 "quality less than a threshold (Mesh.OptimizeThreshold)"));
+  s.push_back(mp("-optimize_ho", "Optimize high order meshes (Mesh.HighOrderOptimize)"));
+  s.push_back(mp("-ho_[min,max,nlayers]", "High-order optimization parameters "
+                 "(Mesh.HighOrderThreshold[Min,Max], Mesh.HighOrderNumLayers)"));
+  s.push_back(mp("-clscale value", "Set mesh element size factor "
+                 "(Mesh.CharacteristicLengthFactor)"));
+  s.push_back(mp("-clmin value", "Set minimum mesh element size "
+                 "(Mesh.CharacteristicLengthMin)"));
+  s.push_back(mp("-clmax value", "Set maximum mesh element size "
+                 "(Mesh.CharacteristicLengthMax)"));
+  s.push_back(mp("-clcurv value", "Compute mesh element size from curvature, with "
+                 "given minimum number of elements per 2*pi radians "
+                 "(Mesh.CharacteristicLengthFromCurvature and "
+                 "Mesh.MinimumElementsPerTwoPi)"));
+  s.push_back(mp("-aniso_max value", "Set maximum anisotropy for bamg (Mesh.AnisoMax)"));
   s.push_back(mp("-smooth_ratio value", "Set smoothing ration between mesh sizes at "
-                 "nodes of a same edge (for bamg)"));
+                 "nodes of a same edge for bamg (Mesh.SmoothRatio)"));
   s.push_back(mp("-epslc1d value", "Set accuracy of evaluation of mesh size field "
-                 "for 1D mesh"));
-  s.push_back(mp("-swapangle value", "Set the threshold angle (in degree) between "
-                 "two adjacent faces below which a swap is allowed"));
-  s.push_back(mp("-rand value", "Set random perturbation factor"));
+                 "for 1D mesh (Mesh.LcIntegrationPrecision)"));
+  s.push_back(mp("-swapangle value", "Set the threshold angle (in degrees) between "
+                 "two adjacent faces below which a swap is allowed "
+                 "(Mesh.AllowSwapAngle)"));
+  s.push_back(mp("-rand value", "Set random perturbation factor (Mesh.RandomFactor)"));
   s.push_back(mp("-bgm file", "Load background mesh from file"));
   s.push_back(mp("-check", "Perform various consistency checks on mesh"));
-  s.push_back(mp("-ignore_periocity", "Ignore periodic boundaries"));
+  s.push_back(mp("-ignore_periocity", "Ignore periodic boundaries "
+                 "(Mesh.IgnorePeriodicity)"));
 #if defined(HAVE_FLTK)
-  s.push_back(mp("Post-processing options:", ""));
-  s.push_back(mp("-link int", "Select link mode between views (0, 1, 2, 3, 4)"));
+  s.push_back(mp("Post-processing:", ""));
+  s.push_back(mp("-link int", "Select link mode between views (PostProcessing.Link)"));
   s.push_back(mp("-combine", "Combine views having identical names into multi-time-step "
                  "views"));
-  s.push_back(mp("Solver options:", ""));
-  s.push_back(mp("-listen", "Always listen to incoming connection requests"));
-  s.push_back(mp("-minterpreter string", "Name of Octave interpreter"));
-  s.push_back(mp("-pyinterpreter string", "Name of Python interpreter"));
+  s.push_back(mp("Solver:", ""));
+  s.push_back(mp("-listen", "Always listen to incoming connection requests "
+                 "(Solver.AlwaysListen)"));
+  s.push_back(mp("-minterpreter string", "Name of Octave interpreter "
+                 "(Solver.OctaveInterpreter)"));
+  s.push_back(mp("-pyinterpreter string", "Name of Python interpreter "
+                 "(Solver.OctaveInterpreter)"));
   s.push_back(mp("-run", "Run ONELAB solver(s)"));
-  s.push_back(mp("Display options:", ""));
-  s.push_back(mp("-n", "Hide all meshes and post-processing views on startup"));
-  s.push_back(mp("-nodb", "Disable double buffering"));
+  s.push_back(mp("Display:", ""));
+  s.push_back(mp("-n", "Hide all meshes and post-processing views on startup "
+                 "(View.Visible, Mesh.[Points,Lines,SurfaceEdges,...])"));
+  s.push_back(mp("-nodb", "Disable double buffering (General.DoubleBuffer)"));
   s.push_back(mp("-numsubedges", "Set num of subdivisions for high order element "
-                 "display"));
-  s.push_back(mp("-fontsize int", "Specify the font size for the GUI"));
-  s.push_back(mp("-theme string", "Specify FLTK GUI theme"));
-  s.push_back(mp("-display string", "Specify display"));
-  s.push_back(mp("-camera", "Use camera mode view;"));
-  s.push_back(mp("-stereo","OpenGL quad-buffered stereo rendering (requires special "
-                 "graphics card)"));
+                 "display (Mesh.NumSubEdges)"));
+  s.push_back(mp("-fontsize int", "Specify the font size for the GUI (General.FontSize)"));
+  s.push_back(mp("-theme string", "Specify FLTK GUI theme (General.FltkTheme)"));
+  s.push_back(mp("-display string", "Specify display (General.Display)"));
+  s.push_back(mp("-camera", "Use camera mode view (General.CameraMode)"));
+  s.push_back(mp("-stereo","OpenGL quad-buffered stereo rendering (General.Stereo)"));
   s.push_back(mp("-gamepad", "Use gamepad controller if available"));
 #endif
-  s.push_back(mp("Other options:", ""));
+  s.push_back(mp("Other:", ""));
   s.push_back(mp("-, -parse_and_exit", "Parse input files, then exit"));
   s.push_back(mp("-new", "Create new model before merge next file"));
   s.push_back(mp("-merge", "Merge next files"));
@@ -154,21 +176,22 @@ std::vector<std::pair<std::string, std::string> > GetUsage()
   s.push_back(mp("-log filename", "Log all messages to filename"));
 #if defined(HAVE_FLTK)
   s.push_back(mp("-a, -g, -m, -s, -p", "Start in automatic, geometry, mesh, solver "
-                 "or post-processing mode"));
+                 "or post-processing mode (General.InitialModule)"));
 #endif
   s.push_back(mp("-pid", "Print process id on stdout"));
   s.push_back(mp("-watch pattern", "Pattern of files to merge as they become "
-                 "available"));
-  s.push_back(mp("-bg file", "Load background (image or PDF) file"));
-  s.push_back(mp("-v int", "Set verbosity level"));
-  s.push_back(mp("-nopopup", "Don't popup dialog windows in scripts"));
+                 "available (General.WatchFilePattern)"));
+  s.push_back(mp("-bg file", "Load background (image or PDF) file "
+                 "(General.BackgroundImageFileName)"));
+  s.push_back(mp("-v int", "Set verbosity level (General.Verbosity)"));
+  s.push_back(mp("-nopopup", "Don't popup dialog windows in scripts (General.NoPopup)"));
   s.push_back(mp("-string \"string\"", "Parse command string at startup"));
   s.push_back(mp("-setnumber name value", "Set constant or option number name=value"));
   s.push_back(mp("-setstring name value", "Set constant or option string name=value"));
   s.push_back(mp("-option file", "Parse option file at startup"));
   s.push_back(mp("-convert files", "Convert files into latest binary formats, "
                  "then exit"));
-  s.push_back(mp("-nt int", "Set number of threads"));
+  s.push_back(mp("-nt int", "Set number of threads (General.NumThreads)"));
   s.push_back(mp("-cpu", "Report CPU times for all operations"));
   s.push_back(mp("-version", "Show version number"));
   s.push_back(mp("-info", "Show detailed version information"));
@@ -607,23 +630,23 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         i++;
       }
       else if(!strcmp(argv[i] + 1, "a")) {
-        CTX::instance()->initialContext = 0;
+        opt_general_initial_context(0, GMSH_SET, 0);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "g")) {
-        CTX::instance()->initialContext = 1;
+        opt_general_initial_context(0, GMSH_SET, 1);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "m")) {
-        CTX::instance()->initialContext = 2;
+        opt_general_initial_context(0, GMSH_SET, 2);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "s")) {
-        CTX::instance()->initialContext = 3;
+        opt_general_initial_context(0, GMSH_SET, 3);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "p")) {
-        CTX::instance()->initialContext = 4;
+        opt_general_initial_context(0, GMSH_SET, 4);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "saveall") ||
@@ -699,7 +722,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         }
       }
       else if(!strcmp(argv[i] + 1, "nopopup")) {
-        CTX::instance()->noPopup = 1;
+        opt_general_nopopup(0, GMSH_SET, 1);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "watch")) {
@@ -707,9 +730,9 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         if(argv[i]){
           std::string tmp = argv[i++];
           if(tmp.size() > 2 && tmp[0] == '"' && tmp[tmp.size() - 1] == '"')
-            CTX::instance()->watchFilePattern = tmp.substr(1, tmp.size() - 2);
+            opt_general_watch_file_pattern(0, GMSH_SET, tmp.substr(1, tmp.size() - 2));
           else
-            CTX::instance()->watchFilePattern = tmp;
+            opt_general_watch_file_pattern(0, GMSH_SET, tmp);
         }
         else{
           Msg::Error("Missing string");
@@ -885,8 +908,8 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
 #endif
           // convert mesh to latest binary format
           if(GModel::current()->getMeshStatus() > 0){
-            CTX::instance()->mesh.mshFileVersion = 4.1;
-            CTX::instance()->mesh.binary = 1;
+            opt_mesh_msh_file_version(0, GMSH_SET, 4.1);
+            opt_mesh_binary(0, GMSH_SET, 1);
             CreateOutputFile(fileName, FORMAT_MSH);
           }
           i++;
@@ -904,7 +927,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       }
       else if(!strcmp(argv[i] + 1, "match")) {
         i++;
-        CTX::instance()->geom.matchGeomAndMesh = 1;
+        opt_geometry_match_geom_and_mesh(0, GMSH_SET, 1);
       }
       else if(!strcmp(argv[i] + 1, "scale")) {
         i++;
@@ -1086,30 +1109,40 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "algo")) {
         i++;
         if(argv[i]) {
-          if(!strncmp(argv[i], "auto", 4))
+          if(!strncmp(argv[i], "MeshAdapt", 9) ||
+             !strncmp(argv[i], "meshadapt", 9) ||
+             !strncmp(argv[i], "iso", 3))
+            opt_mesh_algo2d(0, GMSH_SET, ALGO_2D_MESHADAPT);
+          else if(!strncmp(argv[i], "auto", 4))
             CTX::instance()->mesh.algo2d = ALGO_2D_AUTO;
-          else if(!strncmp(argv[i], "meshadapt", 9) || !strncmp(argv[i], "iso", 3))
-            CTX::instance()->mesh.algo2d = ALGO_2D_MESHADAPT;
-          else if(!strncmp(argv[i], "del2d", 5) || !strncmp(argv[i], "tri", 3))
-            CTX::instance()->mesh.algo2d = ALGO_2D_DELAUNAY;
-          else if(!strncmp(argv[i], "delquad", 7))
-            CTX::instance()->mesh.algo2d = ALGO_2D_FRONTAL_QUAD;
-          else if(!strncmp(argv[i], "pack", 4))
-            CTX::instance()->mesh.algo2d = ALGO_2D_PACK_PRLGRMS;
-          else if(!strncmp(argv[i], "front2d", 7) || !strncmp(argv[i], "frontal", 7))
-            CTX::instance()->mesh.algo2d = ALGO_2D_FRONTAL;
-          else if(!strncmp(argv[i], "bamg",4))
-            CTX::instance()->mesh.algo2d = ALGO_2D_BAMG;
-          else if(!strncmp(argv[i], "del3d", 5) || !strncmp(argv[i], "gmsh3d", 6))
-            CTX::instance()->mesh.algo3d = ALGO_3D_DELAUNAY;
-          else if(!strncmp(argv[i], "hxt", 3) )
-            CTX::instance()->mesh.algo3d = ALGO_3D_HXT;
-          else if(!strncmp(argv[i], "front3d", 7) || !strncmp(argv[i], "netgen", 6))
-            CTX::instance()->mesh.algo3d = ALGO_3D_FRONTAL;
+          else if(!strncmp(argv[i], "Delaunay2D", 5) ||
+                  !strncmp(argv[i], "del2d", 5) ||
+                  !strncmp(argv[i], "tri", 3))
+            opt_mesh_algo2d(0, GMSH_SET, ALGO_2D_DELAUNAY);
+          else if(!strncmp(argv[i], "FrontalDelaunay2D", 16) ||
+                  !strncmp(argv[i], "front2d", 7) ||
+                  !strncmp(argv[i], "frontal", 7))
+            opt_mesh_algo2d(0, GMSH_SET, ALGO_2D_FRONTAL);
+          else if(!strncmp(argv[i], "bamg", 4))
+            opt_mesh_algo2d(0, GMSH_SET, ALGO_2D_BAMG);
+          else if(!strncmp(argv[i], "DelaunayFrontalForQuads", 23) ||
+                  !strncmp(argv[i], "delquad", 7))
+            opt_mesh_algo2d(0, GMSH_SET, ALGO_2D_FRONTAL_QUAD);
+          else if(!strncmp(argv[i], "PackingOfParallelograms", 23) ||
+                  !strncmp(argv[i], "pack", 4))
+            opt_mesh_algo2d(0, GMSH_SET, ALGO_2D_PACK_PRLGRMS);
+          else if(!strncmp(argv[i], "del3d", 5) ||
+                  !strncmp(argv[i], "gmsh3d", 6))
+            opt_mesh_algo3d(0, GMSH_SET, ALGO_3D_DELAUNAY);
+          else if(!strncmp(argv[i], "front3d", 7) ||
+                  !strncmp(argv[i], "netgen", 6))
+            opt_mesh_algo3d(0, GMSH_SET, ALGO_3D_FRONTAL);
           else if(!strncmp(argv[i], "mmg3d", 5))
-            CTX::instance()->mesh.algo3d = ALGO_3D_MMG3D;
+            opt_mesh_algo3d(0, GMSH_SET, ALGO_3D_MMG3D);
           else if(!strncmp(argv[i], "rtree3d", 7))
-            CTX::instance()->mesh.algo3d = ALGO_3D_RTREE;
+            opt_mesh_algo3d(0, GMSH_SET, ALGO_3D_RTREE);
+          else if(!strncmp(argv[i], "hxt", 3) )
+            opt_mesh_algo3d(0, GMSH_SET, ALGO_3D_HXT);
           else{
             Msg::Error("Unknown mesh algorithm");
             if(exitOnError) Msg::Exit(1);
@@ -1137,9 +1170,9 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
             if(exitOnError) Msg::Exit(1);
           }
           else{
-            CTX::instance()->mesh.fileFormat = format;
+            opt_mesh_file_format(0, GMSH_SET, format);
             if(format == FORMAT_MSH && version > 0.)
-              CTX::instance()->mesh.mshFileVersion = version;
+              opt_mesh_msh_file_version(0, GMSH_SET, version);
           }
           i++;
         }
@@ -1150,12 +1183,12 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       }
       else if(!strcmp(argv[i] + 1, "listen")) {
         i++;
-        CTX::instance()->solver.listen = 1;
+        opt_solver_listen(0, GMSH_SET, 1);
       }
       else if(!strcmp(argv[i] + 1, "minterpreter")) {
         i++;
         if(argv[i])
-          CTX::instance()->solver.octaveInterpreter = argv[i++];
+          opt_solver_octave_interpreter(0, GMSH_SET, argv[i++]);
         else{
           Msg::Error("Missing interpreter name");
           if(exitOnError) Msg::Exit(1);
@@ -1164,7 +1197,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "pyinterpreter")) {
         i++;
         if(argv[i])
-          CTX::instance()->solver.pythonInterpreter = argv[i++];
+          opt_solver_python_interpreter(0, GMSH_SET, argv[i++]);
         else{
           Msg::Error("Missing interpreter name");
           if(exitOnError) Msg::Exit(1);
@@ -1173,7 +1206,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "bg")){
         i++;
         if(argv[i])
-          CTX::instance()->bgImageFileName = argv[i++];
+          opt_general_background_image_filename(0, GMSH_SET, argv[i++]);
         else{
           Msg::Error("Missing filename");
           if(exitOnError) Msg::Exit(1);
@@ -1211,9 +1244,8 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       }
       else if(!strcmp(argv[i] + 1, "nt")) {
         i++;
-        if(argv[i]){
+        if(argv[i])
           opt_general_num_threads(0, GMSH_SET, atoi(argv[i++]));
-	}
         else{
           Msg::Error("Missing number");
           if(exitOnError) Msg::Exit(1);
@@ -1225,11 +1257,11 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       }
 #if defined(HAVE_FLTK)
       else if(!strcmp(argv[i] + 1, "dual")) {
-        CTX::instance()->mesh.dual = 1;
+        opt_mesh_dual(0, GMSH_SET, 1);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "voronoi")) {
-        CTX::instance()->mesh.voronoi = 1;
+        opt_mesh_voronoi(0, GMSH_SET, 1);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "noview")) {
@@ -1258,14 +1290,14 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "link")) {
         i++;
         if(argv[i])
-          CTX::instance()->post.link = atoi(argv[i++]);
+          opt_post_link(0, GMSH_SET, atoi(argv[i++]));
         else{
           Msg::Error("Missing number");
           if(exitOnError) Msg::Exit(1);
         }
       }
       else if(!strcmp(argv[i] + 1, "smoothview")) {
-        CTX::instance()->post.smooth = 1;
+        opt_post_smooth(0, GMSH_SET, 1.);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "combine")) {
@@ -1273,7 +1305,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
         i++;
       }
       else if(!strcmp(argv[i] + 1, "nodb")) {
-        CTX::instance()->db = 0;
+        opt_general_double_buffer(0, GMSH_SET, 0.);
         i++;
       }
       else if(!strcmp(argv[i] + 1, "camera")) {
@@ -1291,7 +1323,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "fontsize")) {
         i++;
         if(argv[i])
-          CTX::instance()->fontSize = atoi(argv[i++]);
+          opt_general_fontsize(0, GMSH_SET, atoi(argv[i++]));
         else{
           Msg::Error("Missing number");
           if(exitOnError) Msg::Exit(1);
@@ -1309,7 +1341,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "theme") || !strcmp(argv[i] + 1, "scheme")) {
         i++;
         if(argv[i])
-          CTX::instance()->guiTheme = argv[i++];
+          opt_general_gui_theme(0, GMSH_SET, argv[i++]);
         else{
           Msg::Error("Missing argument");
           if(exitOnError) Msg::Exit(1);
@@ -1318,7 +1350,7 @@ void GetOptions(int argc, char *argv[], bool readConfigFiles, bool exitOnError)
       else if(!strcmp(argv[i] + 1, "display")) {
         i++;
         if(argv[i])
-          CTX::instance()->display = argv[i++];
+          opt_general_display(0, GMSH_SET, argv[i++]);
         else{
           Msg::Error("Missing argument");
           if(exitOnError) Msg::Exit(1);
