@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "MPrism.h"
 #include "Numeric.h"
@@ -595,7 +595,7 @@ void MPrismN::reverse()
   for(int i = 0; i < 6; ++i) {
     _v[i] = oldv[indices[i]];
   }
-  for(unsigned int i = 0; i < _vs.size(); ++i) {
+  for(std::size_t i = 0; i < _vs.size(); ++i) {
     _vs[i] = oldv[indices[6 + i]];
   }
 }
