@@ -15,6 +15,7 @@
 #include "MElementOctree.h"
 #include "Octree.h"
 #include "Context.h"
+#include "GEdgeLoop.h"
 
 #if defined(HAVE_HXT)
 extern "C" {
@@ -95,58 +96,22 @@ discreteFace::discreteFace(GModel *model) : GFace(model, 0)
   // the corresponding entity in GEO internals
 }
 
-static void sort_edges(std::vector<GEdge *> &e, std::vector<int> &dir)
-{
-  if(e.empty() || dir.empty()) return;
-  std::vector<GEdge *> result;
-  result.push_back(e[0]);
-  e.erase(e.begin());
-  dir.clear();
-  dir.push_back(1);
-  while(!e.empty()) {
-    bool found = false;
-    GEdge *ge = result[result.size() - 1];
-    GVertex *gv =
-      dir[dir.size() - 1] == 1 ? ge->getEndVertex() : ge->getBeginVertex();
-    for(size_t i = 0; i < e.size(); i++) {
-      if(e[i]->getBeginVertex() == gv) {
-        found = true;
-        result.push_back(e[i]);
-        e.erase(e.begin() + i);
-        dir.push_back(1);
-        break;
-      }
-      if(e[i]->getEndVertex() == gv) {
-        found = true;
-        result.push_back(e[i]);
-        e.erase(e.begin() + i);
-        dir.push_back(-1);
-        break;
-      }
-    }
-    if(!found && !e.empty()) {
-      result.push_back(e[0]);
-      e.erase(e.begin());
-      dir.push_back(1);
-    }
-  }
-  e = result;
-}
-
 void discreteFace::setBoundEdges(const std::vector<int> &tagEdges)
 {
+  std::vector<GEdge*> e;
   for(std::size_t i = 0; i != tagEdges.size(); i++) {
     GEdge *ge = model()->getEdgeByTag(tagEdges[i]);
     if(ge) {
-      l_edges.push_back(ge);
-      l_dirs.push_back(1);
+      e.push_back(ge);
       ge->addFace(this);
     }
     else {
       Msg::Error("Unknown curve %d in discrete surface %d", tagEdges[i], tag());
     }
   }
-  sort_edges(l_edges, l_dirs);
+  GEdgeLoop el(e);
+  el.getEdges(l_edges);
+  el.getSigns(l_dirs);
 }
 
 void discreteFace::setBoundEdges(const std::vector<int> &tagEdges,
@@ -167,7 +132,6 @@ void discreteFace::setBoundEdges(const std::vector<int> &tagEdges,
       Msg::Error("Unknown curve %d in discrete surface %d", tagEdges[i], tag());
     }
   }
-  sort_edges(l_edges, l_dirs);
 }
 
 int discreteFace::trianglePosition(double par1, double par2, double &u,
@@ -321,12 +285,12 @@ GPoint discreteFace::closestPoint(const SPoint3 &queryPoint, double maxDistance,
 GPoint discreteFace::closestPoint(const SPoint3 &queryPoint,
                                   const double initialGuess[2]) const
 {
-  return closestPoint(queryPoint, 0.1);
+  return closestPoint(queryPoint, 1e-1);
 }
 
 SPoint2 discreteFace::parFromPoint(const SPoint3 &p, bool onSurface) const
 {
-  GPoint gp = closestPoint(p, 0.000001);
+  GPoint gp = closestPoint(p, 1e-6);
   return SPoint2(gp.u(), gp.v());
 }
 
@@ -521,14 +485,12 @@ int discreteFace::createGeometry()
   int nv, ne;
   HXT_CHECK(hxtMeanValuesGetData(param, NULL, NULL, &uvc, &nv, &ne, 1));
   stl_vertices_uv.clear();
-  stl_vertices_uv.resize(nv);
   stl_vertices_xyz.clear();
-  stl_vertices_xyz.resize(nv);
   stl_curvatures.clear();
-  if(model()->getCurvatures().size()) stl_curvatures.resize(2 * nv);
-  stl_normals.clear();
-  stl_normals.resize(nv);
 
+  stl_vertices_uv.resize(nv);
+  stl_vertices_xyz.resize(nv);
+  if(model()->getCurvatures().size()) stl_curvatures.resize(2 * nv);
   for(int iv = 0; iv < nv; iv++) {
     if(model()->getCurvatures().size()) {
       MVertex *v = c2v[iv];
@@ -547,7 +509,6 @@ int discreteFace::createGeometry()
     stl_vertices_xyz[iv] =
       SPoint3(m->vertices.coord[4 * iv + 0], m->vertices.coord[4 * iv + 1],
               m->vertices.coord[4 * iv + 2]);
-    stl_normals[iv] = SVector3(1, 0, 0);
   }
   stl_triangles.clear();
   stl_triangles.resize(3 * ne);
@@ -557,6 +518,7 @@ int discreteFace::createGeometry()
     stl_triangles[3 * ie + 2] = m->triangles.node[3 * ie + 2];
   }
 
+  _computeSTLNormals();
   _createGeometryFromSTL();
 
   HXT_CHECK(hxtMeshDelete(&m));
@@ -566,6 +528,30 @@ int discreteFace::createGeometry()
   return 0;
 }
 
+void discreteFace::_computeSTLNormals()
+{
+  stl_normals.clear();
+  std::size_t T = stl_triangles.size() / 3;
+  std::size_t N = stl_vertices_xyz.size();
+  if(!N || !T) return;
+  stl_normals.resize(N);
+  for(std::size_t i = 0; i < T; i++) {
+    int a = stl_triangles[3 * i + 0];
+    int b = stl_triangles[3 * i + 1];
+    int c = stl_triangles[3 * i + 2];
+    SPoint3 pa(stl_vertices_xyz[a]);
+    SPoint3 pb(stl_vertices_xyz[b]);
+    SPoint3 pc(stl_vertices_xyz[c]);
+    SVector3 vba = pb - pa;
+    SVector3 vca = pc - pa;
+    SVector3 n = crossprod(vba, vca);
+    stl_normals[a] += n;
+    stl_normals[b] += n;
+    stl_normals[c] += n;
+  }
+  for(std::size_t i = 0; i < N; i++) stl_normals[i].normalize();
+}
+
 void discreteFace::_createGeometryFromSTL()
 {
   if(stl_triangles.empty() || stl_vertices_uv.empty() ||
@@ -825,7 +811,6 @@ bool discreteFace::readParametrization(FILE *fp, bool binary)
 {
   stl_vertices_xyz.clear();
   stl_vertices_uv.clear();
-  stl_normals.clear();
   stl_curvatures.clear();
   stl_triangles.clear();
 
@@ -840,7 +825,6 @@ bool discreteFace::readParametrization(FILE *fp, bool binary)
   std::vector<double> d(11 * N);
   stl_vertices_xyz.resize(N);
   stl_vertices_uv.resize(N);
-  stl_normals.resize(N);
   stl_curvatures.resize(2 * N);
   stl_triangles.resize(3 * T);
 
@@ -870,28 +854,13 @@ bool discreteFace::readParametrization(FILE *fp, bool binary)
   for(std::size_t i = 0; i < N; i++) {
     stl_vertices_xyz[i] = SPoint3(d[11 * i + 0], d[11 * i + 1], d[11 * i + 2]);
     stl_vertices_uv[i] = SPoint2(d[11 * i + 3], d[11 * i + 4]);
-    stl_normals[i] = SVector3(0, 0, 0);
     stl_curvatures[2 * i + 0] =
       SVector3(d[11 * i + 5], d[11 * i + 6], d[11 * i + 7]);
     stl_curvatures[2 * i + 1] =
       SVector3(d[11 * i + 8], d[11 * i + 9], d[11 * i + 10]);
   }
-  for(std::size_t i = 0; i < T; i++) {
-    int a = stl_triangles[3 * i + 0];
-    int b = stl_triangles[3 * i + 1];
-    int c = stl_triangles[3 * i + 2];
-    SPoint3 pa(stl_vertices_xyz[a]);
-    SPoint3 pb(stl_vertices_xyz[b]);
-    SPoint3 pc(stl_vertices_xyz[c]);
-    SVector3 vba = pb - pa;
-    SVector3 vca = pc - pa;
-    SVector3 n = crossprod(vba, vca);
-    stl_normals[a] += n;
-    stl_normals[b] += n;
-    stl_normals[c] += n;
-  }
-  for(std::size_t i = 0; i < N; i++) stl_normals[i].normalize();
 
+  _computeSTLNormals();
   _createGeometryFromSTL();
   return true;
 }
