@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -56,28 +56,28 @@ public:
     GFace::addTriangle(t);
     _ghostCells.insert(
       std::pair<MElement *, unsigned int>(t, onWhichPartition));
-    model()->addGhostCells(t, onWhichPartition);
+    model()->addGhostCells(t, _partition);
   }
   virtual void addQuadrangle(MQuadrangle *q, unsigned int onWhichPartition)
   {
     GFace::addQuadrangle(q);
     _ghostCells.insert(
       std::pair<MElement *, unsigned int>(q, onWhichPartition));
-    model()->addGhostCells(q, onWhichPartition);
+    model()->addGhostCells(q, _partition);
   }
   virtual void addPolygon(MPolygon *p, unsigned int onWhichPartition)
   {
     GFace::addPolygon(p);
     _ghostCells.insert(
       std::pair<MElement *, unsigned int>(p, onWhichPartition));
-    model()->addGhostCells(p, onWhichPartition);
+    model()->addGhostCells(p, _partition);
   }
   virtual void addElement(int type, MElement *e, unsigned int onWhichPartition)
   {
     GFace::addElement(type, e);
     _ghostCells.insert(
       std::pair<MElement *, unsigned int>(e, onWhichPartition));
-    model()->addGhostCells(e, onWhichPartition);
+    model()->addGhostCells(e, _partition);
   }
 
   // To make the hidden function visible in ghostFace
