@@ -27,10 +27,6 @@
 #include "Context.h"
 #include "MFace.h"
 
-#if defined(HAVE_OPTHOM)
-#include "HighOrderMeshPeriodicity.h"
-#endif
-
 // for each pair of vertices (an edge), we build a list of vertices that are the
 // high order representation of the edge. The ordering of vertices in the list
 // is supposed to be (by construction) consistent with the ordering of the pair.
@@ -1241,187 +1237,6 @@ static void updateHighOrderVertices(GEntity *e,
   e->deleteVertexArrays();
 }
 
-void FixPeriodicMesh(GModel *m)
-{
-  // Edges
-
-  for(GModel::eiter it = m->firstEdge(); it != m->lastEdge(); ++it) {
-    GEdge *tgt = *it;
-
-    // non complete periodic info (e.g. through extrusion)
-    if(tgt->vertexCounterparts.empty()) continue;
-
-    GEdge *src = dynamic_cast<GEdge *>(tgt->getMeshMaster());
-
-    if(src != NULL && src != tgt) {
-      std::map<MVertex *, MVertex *> &v2v = tgt->correspondingVertices;
-      std::map<MVertex *, MVertex *> &p2p = tgt->correspondingHOPoints;
-      p2p.clear();
-
-      Msg::Info("Reconstructing periodicity for curve connection %d - %d",
-                tgt->tag(), src->tag());
-
-      std::map<MEdge, MLine *, MEdgeLessThan> srcEdges;
-      for(std::size_t i = 0; i < src->getNumMeshElements(); i++) {
-        MLine *srcLine = dynamic_cast<MLine *>(src->getMeshElement(i));
-        if(!srcLine) {
-          Msg::Error("Master element %d is not a line",
-                     src->getMeshElement(i)->getNum());
-          return;
-        }
-        srcEdges[MEdge(srcLine->getVertex(0), srcLine->getVertex(1))] = srcLine;
-      }
-
-      for(std::size_t i = 0; i < tgt->getNumMeshElements(); ++i) {
-        MLine *tgtLine = dynamic_cast<MLine *>(tgt->getMeshElement(i));
-        MVertex *vtcs[2];
-        if(!tgtLine) {
-          Msg::Error("Slave element %d is not a line",
-                     tgt->getMeshElement(i)->getNum());
-          return;
-        }
-        for(int iVtx = 0; iVtx < 2; iVtx++) {
-          MVertex *vtx = tgtLine->getVertex(iVtx);
-          std::map<MVertex *, MVertex *>::iterator tIter = v2v.find(vtx);
-          if(tIter == v2v.end()) {
-            Msg::Error("Cannot find periodic counterpart of node %d"
-                       " of curve %d on curve %d", vtx->getNum(), tgt->tag(),
-                       src->tag());
-            return;
-          }
-          else
-            vtcs[iVtx] = tIter->second;
-        }
-
-        std::map<MEdge, MLine *, MEdgeLessThan>::iterator srcIter =
-          srcEdges.find(MEdge(vtcs[0], vtcs[1]));
-        if(srcIter == srcEdges.end()) {
-          Msg::Error("Can't find periodic counterpart of mesh edge %d-%d "
-                     "on curve %d, connected to mesh edge %d-%d on curve %d",
-                     tgtLine->getVertex(0)->getNum(),
-                     tgtLine->getVertex(1)->getNum(), tgt->tag(),
-                     vtcs[0]->getNum(), vtcs[1]->getNum(), src->tag());
-          return;
-        }
-        else {
-          MLine *srcLine = srcIter->second;
-          for(std::size_t i = 2; i < tgtLine->getNumVertices(); i++)
-            p2p[tgtLine->getVertex(i)] = srcLine->getVertex(i);
-        }
-      }
-    }
-  }
-
-  if(CTX::instance()->mesh.hoPeriodic) {
-#if defined(HAVE_OPTHOM)
-    std::vector<GEntity *> modelEdges(m->firstEdge(), m->lastEdge());
-    HighOrderMeshPeriodicity edgePeriodicity(modelEdges);
-    edgePeriodicity.fixPeriodicity();
-    edgePeriodicity.fixPeriodicity(); // apply twice for operation order effects
-#else
-    Msg::Error("High-order mesh optimization requires the OPTHOM module");
-#endif
-  }
-
-  for(GModel::fiter it = m->firstFace(); it != m->lastFace(); ++it) {
-    GFace *tgt = *it;
-
-    // non complete periodic info (e.g. through extrusion)
-    if(tgt->vertexCounterparts.empty()) continue;
-
-    GFace *src = dynamic_cast<GFace *>(tgt->getMeshMaster());
-    if(src != NULL && src != tgt) {
-      Msg::Info("Reconstructing periodicity for surface connection %d - %d",
-                tgt->tag(), src->tag());
-
-      std::map<MVertex *, MVertex *> &v2v = tgt->correspondingVertices;
-      std::map<MVertex *, MVertex *> &p2p = tgt->correspondingHOPoints;
-      p2p.clear();
-
-      if(tgt->getNumMeshElements() && v2v.empty()){
-        Msg::Info("No periodic vertices in surface %d (maybe due to a "
-                  "structured mesh constraint on the target surface)",
-                  tgt->tag());
-        continue;
-      }
-
-      std::map<MFace, MElement *, MFaceLessThan> srcFaces;
-
-      for(std::size_t i = 0; i < src->getNumMeshElements(); ++i) {
-        MElement *srcElmt = src->getMeshElement(i);
-        int nbVtcs = 0;
-        if(dynamic_cast<MTriangle *>(srcElmt)) nbVtcs = 3;
-        if(dynamic_cast<MQuadrangle *>(srcElmt)) nbVtcs = 4;
-        std::vector<MVertex *> vtcs;
-        vtcs.reserve(nbVtcs);
-        for(int iVtx = 0; iVtx < nbVtcs; iVtx++) {
-          vtcs.push_back(srcElmt->getVertex(iVtx));
-        }
-        srcFaces[MFace(vtcs)] = srcElmt;
-      }
-
-      for(std::size_t i = 0; i < tgt->getNumMeshElements(); ++i) {
-        MElement *tgtElmt = tgt->getMeshElement(i);
-        int nbVtcs = 0;
-        if(dynamic_cast<MTriangle *>(tgtElmt)) nbVtcs = 3;
-        if(dynamic_cast<MQuadrangle *>(tgtElmt)) nbVtcs = 4;
-        std::vector<MVertex *> vtcs;
-        for(int iVtx = 0; iVtx < nbVtcs; iVtx++) {
-          MVertex *vtx = tgtElmt->getVertex(iVtx);
-
-          std::map<MVertex *, MVertex *>::iterator tIter = v2v.find(vtx);
-          if(tIter == v2v.end()) {
-            Msg::Error("Cannot find periodic counterpart of node %d "
-                       "of surface %d on surface %d",
-                       vtx->getNum(), tgt->tag(), src->tag());
-            return;
-          }
-          else
-            vtcs.push_back(tIter->second);
-        }
-
-        MFace tgtFace(vtcs);
-        std::map<MFace, MElement *, MFaceLessThan>::iterator srcIter =
-          srcFaces.find(tgtFace);
-        if(srcIter == srcFaces.end()) {
-          std::ostringstream faceDef;
-          for(int iVtx = 0; iVtx < nbVtcs; iVtx++)
-            faceDef << vtcs[iVtx]->getNum() << " ";
-          Msg::Error("Cannot find periodic counterpart of mesh face %s in "
-                     "surface %d on surface %d",
-                     faceDef.str().c_str(), tgt->tag(), src->tag());
-          return;
-        }
-        else {
-          MElement *srcElmt = srcIter->second;
-          // Warning: this check is made in case the source and target surface
-          // meshes are oriented differently (e.g. to be consistent with the
-          // underlying orientation of the geometrical surfaces)
-          bool revert = dot(tgtFace.normal(), srcIter->first.normal()) < 0;
-          if(revert) srcElmt->reverse();
-          for(std::size_t j = nbVtcs; j < srcElmt->getNumVertices(); j++) {
-            p2p[tgtElmt->getVertex(j)] = srcElmt->getVertex(j);
-          }
-          if(revert) srcElmt->reverse();
-        }
-      }
-    }
-  }
-
-  if(CTX::instance()->mesh.hoPeriodic) {
-#if defined(HAVE_OPTHOM)
-    std::vector<GEntity *> modelFaces;
-    modelFaces.insert(modelFaces.end(), m->firstFace(), m->lastFace());
-    HighOrderMeshPeriodicity facePeriodicity(modelFaces);
-    facePeriodicity.fixPeriodicity();
-#else
-    Msg::Error("High-order mesh optimization requires the OPTHOM module");
-#endif
-  }
-
-  Msg::Debug("Finalized topology of periodic connections");
-}
-
 void SetOrder1(GModel *m, bool onlyVisible)
 {
   m->destroyMeshCaches();
