@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _FILTER_OVERLAPPING_ELEMENTS_
-#define _FILTER_OVERLAPPING_ELEMENTS_
+#ifndef FILTER_OVERLAPPING_ELEMENTS
+#define FILTER_OVERLAPPING_ELEMENTS
 
 #include <map>
 #include <vector>
