@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <sstream>
 #include <stdio.h>
@@ -57,7 +57,7 @@ std::string GMSH_Plugin::serialize()
 PView *GMSH_PostPlugin::executeRemote(PView *view)
 {
   int j = -1, remoteIndex = -1;
-  for(unsigned int i = 0; i < PView::list.size(); i++) {
+  for(std::size_t i = 0; i < PView::list.size(); i++) {
     if(PView::list[i]->getData()->isRemote()) j++;
     if(PView::list[i]->getTag() == view->getTag()) {
       remoteIndex = j;
