@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -360,6 +360,18 @@ bool PView::readMED(const std::string &fileName, int fileIndex)
 
 #endif
 
+bool PView::readPCH(const std::string &fileName, int fileIndex)
+{
+  PViewDataGModel::DataType type = PViewDataGModel::NodeData;
+  // PViewDataGModel::ElementData;
+  // PViewDataGModel::ElementNodeData;
+  PViewDataGModel *d = new PViewDataGModel(type);
+  d->setFileName(fileName);
+  d->readPCH(fileName, fileIndex);
+  new PView(d);
+  return true;
+}
+
 bool PView::write(const std::string &fileName, int format, bool append)
 {
   Msg::StatusBar(true, "Writing '%s'...", fileName.c_str());
