@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _LINEAR_SYSTEM_FULL_H_
-#define _LINEAR_SYSTEM_FULL_H_
+#ifndef LINEAR_SYSTEM_FULL_H
+#define LINEAR_SYSTEM_FULL_H
 
 // Interface to a linear system with a FULL matrix
 
