@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2020 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #if defined(HAVE_PETSC)
 
@@ -120,11 +120,14 @@ void linearSystemPETSc<scalar>::insertInSparsityPattern(int i, int j)
 template <class scalar> void linearSystemPETSc<scalar>::preAllocateEntries()
 {
   if(_entriesPreAllocated) return;
-  if(!_isAllocated) Msg::Fatal("system must be allocated first");
+  if(!_isAllocated){
+    Msg::Error("System must be allocated first");
+    return;
+  }
   int blockSize = _getBlockSizeFromParameters();
   std::vector<int> nByRowDiag(_localSize), nByRowOffDiag(_localSize);
   if(_sparsity.getNbRows() == 0) {
-    PetscInt prealloc = 500;
+    PetscInt prealloc = 100;
     PetscBool set;
     PetscOptionsGetInt(PETSC_NULL, "-petsc_prealloc", &prealloc, &set);
     prealloc = std::min(prealloc, _localSize);
@@ -163,6 +166,14 @@ template <class scalar> void linearSystemPETSc<scalar>::preAllocateEntries()
   }
   if(blockSize > 1) _check(MatSetOption(_a, MAT_ROW_ORIENTED, PETSC_FALSE));
   _entriesPreAllocated = true;
+
+#if ((PETSC_VERSION_MAJOR == 3) && (PETSC_VERSION_MINOR >= 3))
+  // Preallocation routines automatically set now
+  // MAT_NEW_NONZERO_ALLOCATION_ERR, which causes a problem when the mask of the
+  // matrix changes.  We must disable the error generation and allow new
+  // allocation (if needed)
+  _check(MatSetOption(_a, MAT_NEW_NONZERO_ALLOCATION_ERR, PETSC_FALSE));
+#endif
 }
 
 template <class scalar> void linearSystemPETSc<scalar>::allocate(int nbRows)
@@ -219,6 +230,7 @@ template <class scalar> void linearSystemPETSc<scalar>::allocate(int nbRows)
   _localRowEnd = nbRows;
   _globalSize = _localSize;
 #endif
+
   // preallocation option must be set after other options
   _check(VecCreate(_comm, &_x));
   _check(VecSetSizes(_x, blockSize * nbRows, PETSC_DETERMINE));
