@@ -713,7 +713,7 @@ cpp_header="""// {0}
 // Do not edit it directly: it is automatically generated by `api/gen.py'.
 //
 // By design, the {3} C++ API is purely functional, and only uses elementary
-// types from the standard library. See `tutorial/c++' and `demos/api' for
+// types from the C++ standard library. See `tutorial/c++' and `demos/api' for
 // examples.
 
 #if defined(_MSC_VER) && !defined(_USE_MATH_DEFINES)
@@ -771,7 +771,7 @@ c_header="""/*
  * Do not edit it directly: it is automatically generated by `api/gen.py'.
  *
  * By design, the {3} C API is purely functional, and only uses elementary
- * types. See `tutorial/c' and `demos/api' for examples.
+ * C types. See `tutorial/c' and `demos/api' for examples.
  */
 
 #include <stddef.h>
@@ -937,7 +937,7 @@ python_header = """# {0}
 # Do not edit it directly: it is automatically generated by `api/gen.py'.
 #
 # By design, the {2} Python API is purely functional, and only uses elementary
-# types (as well as `numpy' arrays if `numpy' is avaiable). See
+# Python types (as well as `numpy' arrays if `numpy' is available). See
 # `tutorial/python' and `demos/api' for examples.
 
 from ctypes import *
@@ -1122,7 +1122,7 @@ julia_header = """# {0}
 # Do not edit it directly: it is automatically generated by `api/gen.py'.
 #
 # By design, the {2} Julia API is purely functional, and only uses elementary
-# types. See `tutorial/julia' and `demos/api' for examples.
+# Julia types. See `tutorial/julia' and `demos/api' for examples.
 """
 
 def capi(s): return s[:1].upper() + s[1:]
