@@ -12,6 +12,11 @@ extern "C" {
 * \author Célestin Marot
 */
 
+/* usefull macros */
+#define ABS(x) ((x) >= 0 ? (x) : -(x))
+#define MAX(x,y) ((x)>(y) ? (x) : (y))
+#define MIN(x,y) ((x)<(y) ? (x) : (y))
+
 /**
  * Reserve memory space for tetrahedra assuming ntet tetrahedra will be added to the triangulation
  * it is efficient to give ntet = ~8 times the number of vertices to be added
@@ -28,10 +33,6 @@ static inline HXTStatus hxtTetrahedraReserve(HXTMesh* mesh, uint64_t totalTet){
   return HXT_STATUS_OK;
 }
 
-static inline HXTStatus hxtTetrahedraDoubleSize(HXTMesh* mesh) {
-  return hxtTetrahedraReserve(mesh, 2*mesh->tetrahedra.num);
-}
-
 
 /**
  * Remove tetrahedra 't' whose flag indicates they are deleted
@@ -41,18 +42,6 @@ static inline HXTStatus hxtTetrahedraDoubleSize(HXTMesh* mesh) {
  */
 HXTStatus hxtRemoveDeleted(HXTMesh* mesh);
 
-/** Removes ghost tetrahedra */
-HXTStatus hxtRemoveGhosts(HXTMesh* mesh);
-
-/** Adds ghost tetrahedra to adjoin tet. whose neighbors are HXT_NO_ADJACENT.\n
- * THIS FUNCTION SUPPOSE 2 THINGS:
- *  - there are no ghost tetrahedra
- *  - face with 1 tetrahedra (neigh[face]==HXT_NO_ADJACENT) are all on the convex hull
- *
- * this function will not work properly in any other cases...
- */
-HXTStatus hxtAddGhosts(HXTMesh* mesh);
-
 
 #ifdef __cplusplus
 }
