@@ -1,9 +1,12 @@
 import gmsh
+import os
+
 gmsh.initialize()
 
 gmsh.option.setNumber("General.Terminal", 1)
 
-gmsh.merge('step_boundary_colors.stp')
+path = os.path.dirname(os.path.abspath(__file__))
+gmsh.merge(os.path.join(path, 'step_boundary_colors.stp'))
 
 for tag in gmsh.model.getEntities():
     col = gmsh.model.getColor(*tag)
